@@ -9,12 +9,9 @@ A credit is an accounting entry that either increases a liability or equity acco
 or decreases an asset or expense account.
 Credit means "right", gains/income/revenues/liabilities/equity increased with credit.
 """
-import re
 from datetime import datetime, timedelta
 from decimal import Decimal
-
 from math import floor
-
 from django.core.exceptions import ValidationError
 from jacc.helpers import sum_queryset
 from django.conf import settings
@@ -23,7 +20,7 @@ from django.db.models import QuerySet, Q
 from django.utils.timezone import now
 from jutil.cache import CachedFieldsMixin
 from jutil.dict import choices_label
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 CATEGORY_ANY = ''
@@ -112,11 +109,11 @@ class AccountEntry(models.Model):
     type = models.ForeignKey(EntryType, verbose_name=_('type'), related_name='+', on_delete=models.PROTECT, null=True, default=None, blank=True)
     description = models.CharField(verbose_name=_('description'), max_length=256, default='', blank=True)
     amount = models.DecimalField(verbose_name=_('amount'), max_digits=10, decimal_places=2, blank=True, default=None, null=True, db_index=True)
-    source_file = models.ForeignKey(AccountEntrySourceFile, verbose_name=_('account entry source file'), related_name='+', null=True, default=None, blank=True, on_delete=models.CASCADE, help_text='Source for account entry, e.g. received payment (if any)')
-    source_invoice = models.ForeignKey('Invoice', verbose_name=_('source invoice'), null=True, related_name='+', default=None, blank=True, on_delete=models.CASCADE, help_text='For invoice items')
-    settled_invoice = models.ForeignKey('Invoice', verbose_name=_('settled invoice'), null=True, related_name='+', default=None, blank=True, on_delete=models.PROTECT, help_text='For incoming settlements')
-    settled_item = models.ForeignKey('AccountEntry', verbose_name=_('settled item'), null=True, related_name='settlement_set', default=None, blank=True, on_delete=models.PROTECT, help_text='For matched settlements')
-    parent = models.ForeignKey('AccountEntry', verbose_name=_('account.entry.parent'), related_name='child_set', db_index=True, on_delete=models.CASCADE, null=True, default=None, blank=True)
+    source_file = models.ForeignKey(AccountEntrySourceFile, verbose_name=_('account entry source file'), related_name='+', null=True, default=None, blank=True, on_delete=models.CASCADE, help_text=_('entry.source.file.help.text'))  # nopep8, pylint: disable=line-too-long
+    source_invoice = models.ForeignKey('Invoice', verbose_name=_('source invoice'), null=True, related_name='+', default=None, blank=True, on_delete=models.CASCADE, help_text=_('entry.source.invoice.help.text'))  # nopep8, pylint: disable=line-too-long
+    settled_invoice = models.ForeignKey('Invoice', verbose_name=_('settled invoice'), null=True, related_name='+', default=None, blank=True, on_delete=models.PROTECT, help_text=_('entry.settled.invoice.help.text'))  # nopep8, pylint: disable=line-too-long
+    settled_item = models.ForeignKey('AccountEntry', verbose_name=_('settled item'), null=True, related_name='settlement_set', default=None, blank=True, on_delete=models.PROTECT, help_text=_('entry.settled.item.help.text'))  # nopep8, pylint: disable=line-too-long
+    parent = models.ForeignKey('AccountEntry', verbose_name=_('account.entry.parent'), related_name='child_set', db_index=True, on_delete=models.CASCADE, null=True, default=None, blank=True)  # nopep8, pylint: disable=line-too-long
     archived = models.BooleanField(_('archived'), default=False, blank=True)
 
     class Meta:
@@ -128,7 +125,8 @@ class AccountEntry(models.Model):
 
     def clean(self):
         if self.source_invoice and self.settled_invoice:
-            raise ValidationError('Both source_invoice ({}) and settled_invoice ({}) cannot be set same time for account entry ({})'.format(self.source_invoice, self.settled_invoice, self))
+            raise ValidationError('Both source_invoice ({}) and settled_invoice ({}) cannot be set same time for account entry ({})'.format(
+                self.source_invoice, self.settled_invoice, self))
 
     @property
     def balance(self) -> Decimal:
@@ -165,7 +163,7 @@ class Account(models.Model):
     Collects together accounting entries and provides summarizing functionality.
     """
     type = models.ForeignKey(AccountType, verbose_name=_('type'), related_name='+', on_delete=models.PROTECT)
-    name = models.CharField(verbose_name=_('name'), max_length=32, blank=True, default='', db_index=True)
+    name = models.CharField(verbose_name=_('name'), max_length=64, blank=True, default='', db_index=True)
     currency = models.CharField(verbose_name=_('currency'), max_length=3, default='EUR', choices=CURRENCY_TYPE, blank=True)
     created = models.DateTimeField(verbose_name=_('created'), default=now, db_index=True, editable=False, blank=True)
     last_modified = models.DateTimeField(verbose_name=_('last modified'), auto_now=True, db_index=True, editable=False, blank=True)
@@ -203,14 +201,16 @@ class Account(models.Model):
     def needs_settling(self, e: AccountEntry) -> bool:
         """
         Returns True if all of following conditions are True:
-        a) entry type is settlement
-        b) entry has been recorded to this account
-        c) invoice to be settled has been set
-        d) entry has not been settled (=child set empty)
+        a) entry has valid amount set
+        b) entry type is settlement
+        c) entry has been recorded to this account
+        d) invoice to be settled has been set
+        e) entry has not been settled (=child set empty)
         :param e: AccountEntry (settlement)
         :return: bool
         """
-        return e.type and e.type.is_settlement and e.account.id == self.id and e.settled_invoice and AccountEntry.objects.filter(parent=e).count() == 0
+        return e.amount is not None and e.type and e.type.is_settlement and e.account.id == self.id and \
+               e.settled_invoice and AccountEntry.objects.filter(parent=e).count() == 0
 
 
 class InvoiceManager(models.Manager):
@@ -245,9 +245,9 @@ class Invoice(models.Model, CachedFieldsMixin):
     notes = models.TextField(verbose_name=_('notes'), blank=True, default='')
     filename = models.CharField(verbose_name=_('filename'), max_length=255, blank=True, default='', db_index=True)
     amount = models.DecimalField(verbose_name=_('amount'), max_digits=10, decimal_places=2, default=0, blank=True)
-    paid_amount = models.DecimalField(verbose_name=_('paid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)
-    unpaid_amount = models.DecimalField(verbose_name=_('unpaid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)
-    overpaid_amount = models.DecimalField(verbose_name=_('overpaid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)
+    paid_amount = models.DecimalField(verbose_name=_('paid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)  # nopep8, pylint: disable=line-too-long
+    unpaid_amount = models.DecimalField(verbose_name=_('unpaid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)  # nopep8, pylint: disable=line-too-long
+    overpaid_amount = models.DecimalField(verbose_name=_('overpaid amount'), max_digits=10, decimal_places=2, editable=False, blank=True, null=True, default=None, db_index=True)  # nopep8, pylint: disable=line-too-long
     close_date = models.DateTimeField(verbose_name=_('close date'), default=None, null=True, blank=True, db_index=True)
     late_days = models.SmallIntegerField(verbose_name=_('late days'), default=None, null=True, blank=True, db_index=True)
     state = models.CharField(verbose_name=_('state'), max_length=1, blank=True, default='', db_index=True, choices=INVOICE_STATE)
@@ -351,17 +351,14 @@ class Invoice(models.Model, CachedFieldsMixin):
         return sum_queryset(self.receivables)
 
     def get_overpaid_amount(self) -> Decimal:
+        amt = sum_queryset(self.receivables)
         if self.type == INVOICE_CREDIT_NOTE:
-            return max(Decimal('0.00'), sum_queryset(self.receivables))
-        else:
-            return max(Decimal('0.00'), -sum_queryset(self.receivables))
+            return max(Decimal('0.00'), amt)
+        return max(Decimal('0.00'), -amt)
 
     @property
     def is_paid(self) -> bool:
-        if self.type == INVOICE_CREDIT_NOTE:
-            return self.unpaid_amount >= Decimal('0.00')
-        else:
-            return self.unpaid_amount <= Decimal('0.00')
+        return self.unpaid_amount >= Decimal('0.00') if self.type == INVOICE_CREDIT_NOTE else self.unpaid_amount <= Decimal('0.00')
     is_paid.fget.short_description = _('is paid')
 
     @property
@@ -383,8 +380,8 @@ class Invoice(models.Model, CachedFieldsMixin):
                 return first.timestamp
         return None
 
-    def get_late_days(self) -> int:
-        t = self.close_date
+    def get_late_days(self, t: datetime or None = None) -> int:
+        t = self.close_date or t
         if not t:
             t = now()
         return int(floor((t - self.due_date).total_seconds() / 86400.0))
